@@ -5,9 +5,9 @@ build_time_vars = {'ABIFLAGS': '',
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'ar',
+ 'AR': '/usr/bin/ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'BASECFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/local/bin',
@@ -16,31 +16,33 @@ build_time_vars = {'ABIFLAGS': '',
  'BLDSHARED': 'cc -pthread -shared -fPIC -L/usr/local/lib/',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'sparc64-unknown-openbsd7.3',
+ 'BUILD_GNU_TYPE': 'i386-unknown-openbsd7.4',
  'BYTESTR_DEPS': '\\',
  'CC': 'cc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC -O2 '
-           '-pipe -O2 -pipe',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG -O2 '
+           '-pipe   -fPIC -O2 -pipe -O2 -pipe',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -pipe',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+ 'CONFIGURE_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/local/include',
  'CONFIGURE_LDFLAGS': '-L/usr/local/lib/',
- 'CONFIGURE_LDFLAGS_NODIST': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-flto -g',
  'CONFIG_ARGS': "'--enable-shared' '--with-fpectl' '--with-threads' "
                 "'--enable-ipv6' '--with-system-expat' '--with-system-ffi' "
                 "'--with-tcltk-includes=-I/usr/local/include/tcl8.6 "
                 "-I/usr/local/include/tk8.6 -I/usr/X11R6/include' "
                 "'--with-tcltk-libs=-L/usr/X11R6/lib -ltcl86 -ltk86' "
-                "'--enable-loadable-sqlite-extensions' '--prefix=/usr/local' "
+                "'--enable-loadable-sqlite-extensions' '--with-lto' "
+                "'--enable-optimizations' '--prefix=/usr/local' "
                 "'--sysconfdir=/etc' '--mandir=/usr/local/man' "
                 "'--infodir=/usr/local/info' '--localstatedir=/var' "
                 "'--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' "
@@ -49,8 +51,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFINCLUDEDIR': '/usr/local/include',
  'CONFINCLUDEPY': '/usr/local/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/tmp/pobj/Python-3.9.17/Python-3.9.17/coverage.info',
- 'COVERAGE_REPORT': '/build/tmp/pobj/Python-3.9.17/Python-3.9.17/lcov-report',
+ 'COVERAGE_INFO': '/pobj/Python-3.9.18/Python-3.9.18/coverage.info',
+ 'COVERAGE_REPORT': '/pobj/Python-3.9.18/Python-3.9.18/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/local/include',
@@ -70,8 +72,8 @@ build_time_vars = {'ABIFLAGS': '',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
- 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 1,
- 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
+ 'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DTRACE': '',
  'DTRACE_DEPS': '\\',
  'DTRACE_HEADERS': '',
@@ -87,7 +89,7 @@ build_time_vars = {'ABIFLAGS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.cpython-39.so',
  'FILEMODE': 644,
- 'FLOAT_WORDS_BIGENDIAN': 1,
+ 'FLOAT_WORDS_BIGENDIAN': 0,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GITBRANCH': '',
@@ -211,8 +213,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GAMMA': 1,
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
- 'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 1,
+ 'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -263,7 +265,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
  'HAVE_LANGINFO_H': 1,
- 'HAVE_LARGEFILE_SUPPORT': 0,
+ 'HAVE_LARGEFILE_SUPPORT': 1,
  'HAVE_LCHFLAGS': 0,
  'HAVE_LCHMOD': 0,
  'HAVE_LCHOWN': 1,
@@ -520,16 +522,16 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'sparc64-unknown-openbsd7.3',
+ 'HOST_GNU_TYPE': 'i386-unknown-openbsd7.4',
  'INCLDIRSTOMAKE': '/usr/local/include /usr/local/include '
                    '/usr/local/include/python3.9 /usr/local/include/python3.9',
  'INCLUDEDIR': '/usr/local/include',
  'INCLUDEPY': '/usr/local/include/python3.9',
- 'INSTALL': '/build/tmp/pobj//Python-3.9.17/bin/install -c',
- 'INSTALL_DATA': '/build/tmp/pobj//Python-3.9.17/bin/install -c -m 644',
- 'INSTALL_PROGRAM': '/build/tmp/pobj//Python-3.9.17/bin/install -c -s -m 755',
- 'INSTALL_SCRIPT': '/build/tmp/pobj//Python-3.9.17/bin/install -c -m 755',
- 'INSTALL_SHARED': '/build/tmp/pobj//Python-3.9.17/bin/install -c -m 755',
+ 'INSTALL': '/pobj/Python-3.9.18/bin/install -c',
+ 'INSTALL_DATA': '/pobj/Python-3.9.18/bin/install -c -m 644',
+ 'INSTALL_PROGRAM': '/pobj/Python-3.9.18/bin/install -c -s -m 755',
+ 'INSTALL_SCRIPT': '/pobj/Python-3.9.18/bin/install -c -m 755',
+ 'INSTALL_SHARED': '/pobj/Python-3.9.18/bin/install -c -m 755',
  'INSTSONAME': 'libpython3.9.so.0.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
@@ -635,46 +637,52 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                             '-pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 '
-                             '-Wextra -Wno-unused-result -Wno-unused-parameter '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
+                             '-Wunreachable-code -DNDEBUG -O2 -pipe   -fPIC '
+                             '-O2 -pipe -O2 -pipe -flto -g -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden -I/usr/local/include '
+                             '-fprofile-instr-use=code.profclangd '
                              '-I./Include/internal -I. -I./Include '
                              '-I/usr/local/include -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe   -fPIC '
-              '-O2 -pipe -O2 -pipe',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code -DNDEBUG '
+              '-O2 -pipe   -fPIC -O2 -pipe -O2 -pipe',
+ 'PY_CFLAGS_NODIST': '-flto -g -std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden -I/usr/local/include '
-                     '-I./Include/internal',
+                     '-fprofile-instr-use=code.profclangd -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe   '
-                   '-fPIC -O2 -pipe -O2 -pipe -std=c99 -Wextra '
-                   '-Wno-unused-result -Wno-unused-parameter '
-                   '-Wno-missing-field-initializers '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                   '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto -g '
+                   '-std=c99 -Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-I/usr/local/include -I./Include/internal -I. -I./Include '
-                   '-I/usr/local/include -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ '
-                    '-L/build/tmp/pobj//Python-3.9.17/Python-3.9.17 '
-                    '-L/usr/local/lib/',
+                   '-I/usr/local/include -fprofile-instr-use=code.profclangd '
+                   '-I./Include/internal -I. -I./Include -I/usr/local/include '
+                   '-fPIC -DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-L/usr/local/lib/ -flto -g '
+                    '-L/pobj/Python-3.9.18/Python-3.9.18 -L/usr/local/lib/',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/local/include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-L/usr/local/lib/',
- 'PY_LDFLAGS_NODIST': '-L/build/tmp/pobj//Python-3.9.17/Python-3.9.17 '
+ 'PY_LDFLAGS_NODIST': '-flto -g -L/pobj/Python-3.9.18/Python-3.9.18 '
                       '-L/usr/local/lib/',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
-                        '-pipe   -fPIC -O2 -pipe -O2 -pipe -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -Wunreachable-code '
+                        '-DNDEBUG -O2 -pipe   -fPIC -O2 -pipe -O2 -pipe -flto '
+                        '-g -std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden -I/usr/local/include '
+                        '-fprofile-instr-use=code.profclangd '
                         '-I./Include/internal -I. -I./Include '
                         '-I/usr/local/include -fPIC',
  'Py_DEBUG': 0,
@@ -685,7 +693,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.17/Python-3.9.17',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/pobj/Python-3.9.18/Python-3.9.18',
  'SCRIPTDIR': '/usr/local/lib',
  'SETPGRP_HAVE_ARG': 1,
  'SHELL': '/bin/sh',
@@ -698,18 +706,18 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FLOAT': 4,
  'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
- 'SIZEOF_LONG': 8,
- 'SIZEOF_LONG_DOUBLE': 16,
+ 'SIZEOF_LONG': 4,
+ 'SIZEOF_LONG_DOUBLE': 12,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
  'SIZEOF_PTHREAD_KEY_T': 4,
- 'SIZEOF_PTHREAD_T': 8,
+ 'SIZEOF_PTHREAD_T': 4,
  'SIZEOF_SHORT': 2,
- 'SIZEOF_SIZE_T': 8,
+ 'SIZEOF_SIZE_T': 4,
  'SIZEOF_TIME_T': 8,
- 'SIZEOF_UINTPTR_T': 8,
- 'SIZEOF_VOID_P': 8,
+ 'SIZEOF_UINTPTR_T': 4,
+ 'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39',
@@ -727,11 +735,10 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '-L/usr/X11R6/lib -ltcl86 -ltk86',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.17/Python-3.9.17 '
-               './python',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/pobj/Python-3.9.18/Python-3.9.18 ./python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/tmp/pobj/Python-3.9.17/Python-3.9.17 '
-               './python ./Tools/scripts/run_tests.py',
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/pobj/Python-3.9.18/Python-3.9.18 ./python '
+               './Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -751,10 +758,10 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_VALGRIND': 0,
- 'X87_DOUBLE_ROUNDING': 0,
+ 'X87_DOUBLE_ROUNDING': 1,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/tmp/pobj/Python-3.9.17/Python-3.9.17',
- 'abs_srcdir': '/build/tmp/pobj/Python-3.9.17/Python-3.9.17',
+ 'abs_builddir': '/pobj/Python-3.9.18/Python-3.9.18',
+ 'abs_srcdir': '/pobj/Python-3.9.18/Python-3.9.18',
  'datarootdir': '/usr/local/share',
  'exec_prefix': '/usr/local',
  'prefix': '/usr/local',
